@@ -125,6 +125,7 @@ arrange.random_steps <- function(.data, ..., .dots) {
   rsteps_transfer_attr(.data, xx)
 }
 
+
 #' @export
 filter.random_steps <- function(.data, ..., .dots) {
   xx <- NextMethod()
@@ -137,6 +138,11 @@ group_by.random_steps <- function(.data, ..., .dots) {
   rsteps_transfer_attr(.data, xx)
 }
 
+#' @export
+nest.random_steps <- function(.data, ..., .dots) {
+  NextMethod()
+}
+
 #' @export
 select.random_steps <- function(.data, ..., .dots) {
   xx <- NextMethod()
