@@ -372,6 +372,10 @@ arrange.steps_xy <- function(.data, ..., .dots) {
   steps_transfer_attr(.data, xx)
 }
 
+count.steps_xy <- function(.data, ..., .dots) {
+  NextMethod()
+}
+
 #' @export
 filter.steps_xy <- function(.data, ..., .dots) {
   xx <- NextMethod()
@@ -390,6 +394,11 @@ mutate.steps_xy <- function(.data, ..., .dots) {
   steps_transfer_attr(.data, xx)
 }
 
+#' @export
+nest.steps_xy <- function(.data, ..., .dots) {
+  NextMethod()
+}
+
 #' @export
 select.steps_xy <- function(.data, ..., .dots) {
   xx <- NextMethod()
